<?php
/**
 * Rain by Flutterum Theme Customizer
 *
 * @package Rain by Flutterum

 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function rain_by_flutterum_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'rain_by_flutterum_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'rain_by_flutterum_customize_partial_blogdescription',
			)
		);
		//Body text color
		$wp_customize->add_setting( 'body_textcolor' , array(
			'default'     => "#222222",
			'transport'   => 'refresh',
			'sanitize_callback' => 'sanitize_hex_color',
		) );
	
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'body_textcolor', array(
			'label'        => esc_html__( 'Body Text Color', 'rain-by-flutterum' ),
			'section'    => 'colors',
		) ) );
		//Menu color
		$wp_customize->add_setting( 'menu_textcolor' , array(
			'default'     => "#0076d1",
			'transport'   => 'refresh',
			'sanitize_callback' => 'sanitize_hex_color',
		) );
	
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'menu_textcolor', array(
			'label'        => esc_html__( 'Menu Text Color', 'rain-by-flutterum' ),
			'section'    => 'colors',
		) ) );
	    // Main Link color
		$wp_customize->add_setting( 'links_textcolor' , array(
			'default'     => "#0076d1",
			'transport'   => 'refresh',
			'sanitize_callback' => 'sanitize_hex_color',
		) );
	
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'links_textcolor', array(
			'label'        => esc_html__( 'Main Links Color', 'rain-by-flutterum' ),
			'section'    => 'colors',
		) ) );
	    //Footer Link color
		$wp_customize->add_setting( 'foot_links_textcolor' , array(
			'default'     => "#0076d1",
			'transport'   => 'refresh',
			'sanitize_callback' => 'sanitize_hex_color',
		) );
	
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'foot_links_textcolor', array(
			'label'        => esc_html__( 'Footer Links Color', 'rain-by-flutterum' ),
			'section'    => 'colors',
		) ) );
		$wp_customize->add_setting( 'rain_by_flutterum_footer_text', array(
			'capability' => 'edit_theme_options',
			'default' => 'Just another WordPress footer',
			'sanitize_callback' => 'wp_kses_post',
		  ) );
		  $wp_customize->add_control( 'rain_by_flutterum_footer_text', array(
			'type' => 'text',
			'section' => 'title_tagline',
			'label' => esc_html__( 'Footer Text', 'rain-by-flutterum' ),
		  ) );
	}	
}
add_action( 'customize_register', 'rain_by_flutterum_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function rain_by_flutterum_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function rain_by_flutterum_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function rain_by_flutterum_customize_preview_js() {
	wp_enqueue_script( 'rain-by-flutterum-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), rain_by_flutterum_VERSION, true );
}
add_action( 'customize_preview_init', 'rain_by_flutterum_customize_preview_js' );

/**
 * Custom links coloring.
 */
function rain_by_flutterum_customize_links_css()
{
    ?>
    <style>
        .site-main a, .widget a { color: <?php echo esc_html(get_theme_mod('links_textcolor', "#000000")); ?>; }
		footer a { color: <?php echo esc_html(get_theme_mod('foot_links_textcolor', "#000000")); ?>; }
		body, p, .footer-text, h2, h3, h4, h5, h6, time, button, input, textarea, select { color: <?php echo esc_html(get_theme_mod('body_textcolor', "#000000")); ?>; }
		.menu-container li a, .menu-item a, .main-navigation ul a, .main-navigation ul a:visited, .main-navigation ul button { color: <?php echo esc_html(get_theme_mod('menu_textcolor', "#000000")); ?>; }
		.menu-container li.current-menu-item a { color: <?php echo esc_html(get_theme_mod('menu_textcolor', "#000000")); ?>; font-weight:bold; }
    </style>
    <?php
}
add_action( 'wp_head', 'rain_by_flutterum_customize_links_css');